@@ -4,7 +4,7 @@ from collections import namedtuple
 import numpy as np
 from jax import numpy as jnp
 import networkx as nx
-from decayangle.lorentz import LorentzTrafo
+from decayangle.lorentz import LorentzTrafo, WignerAngles
 from decayangle import kinematics as akm
 from decayangle.numerics_helpers import matrix_vector_product
 from decayangle.config import config as cfg
@@ -336,35 +336,37 @@ class Node:
         xi = -akm.rapidity(target.momentum(momenta))
         boost = LorentzTrafo(zero, zero, xi, zero, zero, zero)
 
+        if convention == "canonical":
+            rotation, minus_theta_rf, minus_psi_rf = self.rotate_to(
+                target, momenta, tol=tol
+            )
+            # return here, since we do not need particle 2 convention
+            return rotation.inverse() @ boost @ rotation
+
+        # particle 2 convention requires, that we move to particle 2 as Lambda_1 * Rot_y(-pi)
         if convention == "helicity":
-            # rotate so that the target momentum is aligned with the z axis of daughter 1
             rotation_daughter1, minus_theta_rf, minus_psi_rf = self.rotate_to(
                 self.daughters[0], momenta, tol=tol
             )
             rotation = rotation_daughter1
-            if target != self.daughters[0]:
-                # if the target is daughter 2, we have to turn around before boosting
-                rotation = LorentzTrafo(0, 0, 0, 0, -cb.pi, -cb.pi) @ rotation_daughter1
-            full_transformation = boost @ rotation
+
         elif convention == "minus_phi":
-            rotation, minus_theta_rf, minus_psi_rf = self.rotate_to(
-                target, momenta, tol=tol
+            _, minus_theta_rf, minus_psi_rf = self.rotate_to(
+                self.daughters[0], momenta, tol=tol
             )
-            full_transformation = (
-                LorentzTrafo(zero, zero, zero, zero, zero, minus_psi_rf)
-                @ boost
-                @ rotation
+            rotation = LorentzTrafo(
+                zero, zero, zero, -minus_psi_rf, minus_theta_rf, minus_psi_rf
             )
-        elif convention == "canonical":
-            rotation, minus_theta_rf, minus_psi_rf = self.rotate_to(
-                target, momenta, tol=tol
-            )
-            full_transformation = rotation.inverse() @ boost @ rotation
+
         else:
             raise ValueError(
                 f"Convention {convention} not supported. Use 'helicity', 'minus_phi' or 'canonical'."
             )
 
+        if target != self.daughters[0]:
+            rotation = LorentzTrafo(0, 0, 0, 0, -cb.pi, 0) @ rotation
+        full_transformation = boost @ rotation
+
         return full_transformation
 
     def align_with_daughter(
@@ -468,7 +470,6 @@ class Node:
         # rotate so that the target momentum is aligned with the z axis
         minus_phi_rf, minus_theta_rf = akm.rotate_to_z_axis(target.momentum(momenta))
         rotation = LorentzTrafo(zero, zero, zero, zero, minus_theta_rf, minus_phi_rf)
-
         return rotation, minus_theta_rf, minus_phi_rf
 
 
@@ -767,10 +768,16 @@ class Topology:
         Returns:
             The rotation between the two rest frames for the target node, one arrives at by boosting from the mother rest frame to the target rest frame as described by the two topologies
         """
+        if convention not in ["helicity", "minus_phi", "canonical"]:
+            raise ValueError(
+                f"Convention {convention} not supported. Use 'helicity', 'minus_phi' or 'canonical'."
+            )
+        if self == other:
+            return LorentzTrafo(0, 0, 0, 0, 0, 0)
         target = Node.get_node(target)
         # invert self, since this final state is seen as the reference
         boost1_inv = self.boost(
-            target, momenta, inverse=True, tol=tol, convention=convention
+            target, momenta, tol=tol, convention=convention, inverse=True
         )
         boost2 = other.boost(target, momenta, tol=tol, convention=convention)
         return boost2 @ boost1_inv
