@@ -37,9 +37,29 @@ def test_lotentz(boost_definitions):
         assert np.allclose(psi, psi_)
         assert np.allclose(theta, theta_)
         assert np.allclose(xi, xi_)
-        assert np.allclose(phi_rf, phi_rf_)
-        assert np.allclose(theta_rf, theta_rf_)
-        assert np.allclose(psi_rf, psi_rf_)
+        assert np.allclose(
+            matrix_2x2, build_2_2(psi_, theta_, xi_, theta_rf_, phi_rf_, psi_rf_)
+        )
+
+    for boost_definition in boost_definitions:
+        single_test(*boost_definition)
+
+
+def test_lotentz_su_2_direct(boost_definitions):
+    def single_test(psi, theta, xi, theta_rf, phi_rf, psi_rf):
+        M = build_4_4(psi, theta, xi, theta_rf, phi_rf, psi_rf)
+        matrix_2x2 = build_2_2(psi, theta, xi, theta_rf, phi_rf, psi_rf)
+        trafo = LorentzTrafo(psi, theta, xi, theta_rf, phi_rf, psi_rf)
+        psi_, theta_, xi_, theta_rf_, phi_rf_, psi_rf_ = trafo.decode(
+            method="su2_decode"
+        )
+        assert np.allclose(M, build_4_4(psi_, theta_, xi_, theta_rf_, phi_rf_, psi_rf_))
+        assert np.allclose(psi, psi_)
+        assert np.allclose(theta, theta_)
+        assert np.allclose(xi, xi_)
+        assert np.allclose(
+            matrix_2x2, build_2_2(psi_, theta_, xi_, theta_rf_, phi_rf_, psi_rf_)
+        )
 
     for boost_definition in boost_definitions:
         single_test(*boost_definition)
@@ -501,11 +521,3 @@ def test_conventions(momenta):
         momenta,
         convention="invalid",
     )
-
-
-if __name__ == "__main__":
-    test_lotentz(boost_definitions())
-    test_lotentz2(boost_definitions())
-    test_helicity_angles()
-    test_conventions(np.random.rand(4, 3))
-    test_daltiz_plot_decomposition([np.random.rand(3, 100, 3) for _ in range(3)])
